pub fn borrow(row: &[OwnedDatum]) -> Vec<Datum<'_>>Expand description
Borrows an owned row, for handing to the tree builder.
@param row - the owned row
pub fn borrow(row: &[OwnedDatum]) -> Vec<Datum<'_>>Borrows an owned row, for handing to the tree builder.
@param row - the owned row